ErrorCode

Struct ErrorCode 

pub struct ErrorCode;
Standard JSON-RPC 2.0 error codes.

The range from -32768 to -32000 is reserved for pre-defined errors. The range from -32000 to -32099 is reserved for server errors. All other codes are available for application-defined errors.

Implementations

Source

impl ErrorCode

pub const PARSE_ERROR: i32 = -32700

Invalid JSON was received by the server. An error occurred on the server while parsing the JSON text.

pub const INVALID_REQUEST: i32 = -32600

The JSON sent is not a valid Request object.

pub const METHOD_NOT_FOUND: i32 = -32601

The method does not exist / is not available.

pub const INVALID_PARAMS: i32 = -32602

Invalid method parameter(s).

pub const INTERNAL_ERROR: i32 = -32603

Internal JSON-RPC error.

pub const SERVER_ERROR_MIN: i32 = -32099

The lowest reserved server error code.

pub const SERVER_ERROR_MAX: i32 = -32000

The highest reserved server error code.

pub fn is_reserved(code: i32) -> bool

Returns true if the given code is in the reserved pre-defined error range.

pub fn is_server_error(code: i32) -> bool

Returns true if the given code is in the server error range.

pub fn default_message(code: i32) -> &'static str

Returns a human-readable default message for a given standard error code.